# Registering and loading an attack

::: agentdojo.attacks.attack_registry.load_attack
    options:
        heading_level: 2

::: agentdojo.attacks.attack_registry.register_attack
    options:
        heading_level: 2
